#!/usr/bin/env python3
# -*- coding: utf-8 -*-

'''
Created on 2016年3月18日
@author: zeb
'''

# import modules
import ogr, os, psycopg2
from PIL import Image,ImageDraw
from pyproj import Proj
import sys

def locProj(point, pro):
    return pro(point)

def drawPolygon(geom, draw, w, h, minlng, maxlng, minlat, maxlat, pro):
    for j in range(0, geom.GetGeometryCount()):
        item = geom.GetGeometryRef(j)
        pts = []
        for i in range(0, item.GetPointCount()):
            p1 = item.GetPoint(i)
            p1=pro(p1[0],p1[1])
            p1=(0.25*w+0.5*w*(p1[0]-minlng)/(maxlng-minlng),0.25*h+0.5*(h-h*(p1[1]-minlat)/(maxlat-minlat)))
            pts.append(p1)
        draw.polygon(pts, fill=128, outline=(100,190,20))
    return

#set server info
hosti='localhost'
porti=5432
useri='postgres'
pwdi='postgres'
dbi='mydb'

# set the working directory
os.chdir('/home/zeb/CHN_adm')

#connect the server
conn = psycopg2.connect(host=hosti, port=porti, user=useri, password=pwdi,database=dbi)
cur = conn.cursor()

#import shapefile
#execute some sqls
cur.execute('DROP TABLE IF EXISTS public.chn_adm3;')
# get the shapefile driver
driver = ogr.GetDriverByName('ESRI Shapefile')
#create table
cur.execute('CREATE TABLE public.CHN_adm3 (gid int4 NOT NULL primary key, name0 varchar(50), name1 varchar(50), name2 varchar(50), name3 varchar(50), geom public.geometry) ;')
#open shp file
shapefile = driver.Open('CHN_adm3.shp') 
if shapefile is None:
    print ('Could not open file')
    sys.exit(1)
layer = shapefile.GetLayer()
for i in range(layer.GetFeatureCount()):  
    feature = layer.GetFeature(i)
    name0 = feature.GetField("NAME_0")#.decode("utf-8")
    name1 = feature.GetField("NAME_1")#.decode("utf-8")
    name2 = feature.GetField("NAME_2")#.decode("utf-8")  
    name3 = feature.GetField("NAME_3")#.decode("utf-8")
    fid =i
    wkt = feature.GetGeometryRef().ExportToWkt()
    cur.execute("INSERT INTO public.CHN_adm3  (gid, name0, name1, name2, name3, geom) " +"VALUES (%s, %s, %s, %s, %s, ST_GeometryFromText(%s, " +"4326));", (fid, name0, name1, name2, name3, wkt))
conn.commit()
print('Shapefile import successfully!')

#draw and project a  shp on an image
#define the projection
pro=Proj('+proj=aea +lon_0=105 +lat_1=25 +lat_2=47 +ellps=krass')#Albers投影

#create the image
cur.execute("SELECT ST_XMin(bbox.geom), ST_XMax(bbox.geom), ST_YMin(bbox.geom), ST_YMax(bbox.geom) FROM (SELECT ST_Envelope(ST_Union(geom)) AS geom FROM public.CHN_adm3) AS bbox")
bbox = cur.fetchone()
minlng,minlat=pro(bbox[0],bbox[2])
maxlng,maxlat=pro(bbox[1],bbox[3])
w = 1280
h = int(w * (maxlat - minlat) / (maxlng - minlng))
img = Image.new("RGB", (w, h), "white")
draw = ImageDraw.Draw(img)
#draw geometry
cur.execute('select gid, name0, name1, name2, name3, ST_AsText(geom) AS geom from public.CHN_adm3;')
shp=cur.fetchall()
for row in shp:
    # print row[1]
    ob = ogr.CreateGeometryFromWkt(row[5])    
    gtype=ob.GetGeometryName()
    #print(gtype)
    if gtype=='MULTIPOLYGON':
        for j in range(0, ob.GetGeometryCount()):
                item = ob.GetGeometryRef(j)
                drawPolygon(item, draw,w, h, minlng, maxlng, minlat, maxlat,pro)
    else:
        drawPolygon(ob, draw,w, h, minlng, maxlng, minlat, maxlat,pro)
#save image
img.save('ChinaPro.jpg', 'JPEG')
print('Draw shp successfully!')
cur.close()
conn.close()


