#!/usr/bin/env python3
# -*- coding: utf-8 -*-


# import modules
import ogr, os, sys, psycopg2
from pyproj import Proj 
from PIL import Image,ImageDraw

#define a projection
p=Proj('+proj=aea +lon_0=105 +lat_1=25 +lat_2=47 +ellps=krass')

def drawPolygon(geom, draw, w, h, minlng, maxlng, minlat, maxlat):
    for j in range(0, geom.GetGeometryCount()):
        item = geom.GetGeometryRef(j)
        for i in range(0, item.GetPointCount()-2):
            p1 = item.GetPoint(i)
            buffer_x,buffer_y=p(p1[0],p1[1])
            new_p1=(w*(buffer_x-minlng)/(maxlng-minlng),h-h*(buffer_y-minlat)/(maxlat-minlat)) 
            p2 = item.GetPoint(i + 1)
            buffer_x,buffer_y=p(p2[0],p2[1])
            new_p2=(w*(buffer_x-minlng)/(maxlng-minlng),h-h*(buffer_y-minlat)/(maxlat-minlat))
            draw.line(new_p1 + new_p2, fill=128)
        p1 = item.GetPoint(item.GetPointCount()-1)
        p1=(w*(p1[0]-minlng)/(maxlng-minlng),h-h*(p1[1]-minlat)/(maxlat-minlat))
        p2 = item.GetPoint(0)
        p2=(w*(p2[0]-minlng)/(maxlng-minlng),h-h*(p2[1]-minlat)/(maxlat-minlat))
        draw.line(p1 + p2, fill=128)
    return



# set the working directory
os.chdir('/home/liumin/CHN_adm')



#import shapefile
#execute some sqls
#cur.execute('DROP TABLE IF EXISTS public.chn_adm3;')
# get the shapefile driver
driver = ogr.GetDriverByName('ESRI Shapefile')
#create table
#cur.execute('CREATE TABLE public.CHN_adm3 (gid int4 NOT NULL primary key, name0 varchar(50), name1 varchar(50), name2 varchar(50), name3 varchar(50), geom public.geometry) ;')
#open shp file
shapefile = driver.Open('CHN_adm3.shp') 
if shapefile is None:
    print ('Could not open file')
    sys.exit(1)
layer = shapefile.GetLayer()
#get Extent of the shp
extent=layer.GetExtent()
minlng = extent[0]
maxlng = extent[1]
minlat = extent[2]
maxlat = extent[3]
buffer_lng,buffer_lat=p(minlng,minlat)
minlng,minlat=buffer_lng,buffer_lat
buffer_lng,buffer_lat=p(maxlng,maxlat)
maxlng,maxlat=buffer_lng,buffer_lat
print(extent)
w = 1280
h = int(w * (maxlat - minlat) / (maxlng - minlng))
img = Image.new("RGB", (w, h), "white")
draw = ImageDraw.Draw(img)
##
for i in range(layer.GetFeatureCount()):  
    feature = layer.GetFeature(i)
    name0 = feature.GetField("NAME_0")#.decode("utf-8")
    fid =i
    wkt = feature.GetGeometryRef().ExportToWkt()
    ob = ogr.CreateGeometryFromWkt(wkt)    
    gtype=ob.GetGeometryName()
    #print(gtype)
    if gtype=='MULTIPOLYGON':
        for j in range(0, ob.GetGeometryCount()):
                item = ob.GetGeometryRef(j)
                drawPolygon(item, draw,w, h, minlng, maxlng, minlat, maxlat)
    else:
        drawPolygon(ob, draw,w, h, minlng, maxlng, minlat, maxlat)
    
#draw geometry
#save image
img.save('China.jpg', 'JPEG')
print('Draw  successfully!')




    

